@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/gui.h,v 12.3 2014/01/05 11:05:48 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/gui.h,v 12.5 2019/06/06 09:25:14 jcb Exp $
  * gui.h
  * type defns and forward declarations for the gui module.
  */
@@ -263,7 +263,7 @@ void prefs_updater_callback(GtkWidget *w, gpointer data);
 int read_or_update_rcfile(char *rcfile,
   XmjrcGroup read_groups,
   XmjrcGroup update_groups);
-void scorehistorywindow_init(void);
+void scorehistory_init(void);
 void scoring_dialog_init(void);
 void scoring_dialog_popup(void);
 void set_dialog_posn(DialogPosition p);
@@ -417,6 +417,7 @@ extern char table_colour_name[]; /* colour of the table background */
 extern int animate; /* do fancy animation */
 extern int nopopups; /* suppress automatic popup of message/scoring windows */
 extern int tiletips; /* show tiletips constantly */
+extern int rotatelabels; /* rotate player info labels on table */
 extern int showwall; /* show the wall or not */
 extern int sort_tiles; /* when to sort tiles */
 extern int info_windows_in_main; /* should the message and game info windows
